@@ -660,25 +660,23 @@ void MainWindow::updatePlaylistModel()
     for(qint32 pos=0; pos < m_Playlists.size(); pos++)
     {
         Spotify::Playlist* pl = m_Playlists.at(pos);
-        QStandardItem *item = new QStandardItem();
-        item->setEditable(false);
-        if(pl->getOfflineStatus()!=Spotify::Available) //playlist not offline
-            item->setData(listTypeIcon,ListViewDelegate::iconRole);
-        else
-            item->setData(listTypeOfflineIcon,ListViewDelegate::iconRole);  //offline playlist
-        item->setData(pl->getName(),ListViewDelegate::headerRole);
-        item->setData(QString::number(pl->getNumTracks()) + " " + tr("tracks"),ListViewDelegate::subHeaderLeftJustifyRole);
         if(pl->getOfflineStatus() != Spotify::Available && m_pSession->isOfflineMode())
         {//we are currently in offline mode, and the playlist has not been synced for offline usage
-            item->setEnabled(false);
-            item->setData(-1,ListViewDelegate::customDataRole);
+            continue; //skip list (do not display list in the listview)
         }
         else
         {
-            item->setEnabled(true);
+            QStandardItem *item = new QStandardItem();
+            item->setEditable(false);
+            if(pl->getOfflineStatus()!=Spotify::Available) //playlist not available offline
+                item->setData(listTypeIcon,ListViewDelegate::iconRole);
+            else
+                item->setData(listTypeOfflineIcon,ListViewDelegate::iconRole);  //offline playlist
+            item->setData(pl->getName(),ListViewDelegate::headerRole);
+            item->setData(QString::number(pl->getNumTracks()) + " " + tr("tracks"),ListViewDelegate::subHeaderLeftJustifyRole);
             item->setData(pos,ListViewDelegate::customDataRole); //store associated position in playlist instance list
+            m_pPlaylistModel->appendRow(item);
         }
-        m_pPlaylistModel->appendRow(item);
     }
 }
 
